@@ -1,10 +1,11 @@
 from typing import Any, Callable
 
 from ruamel import yaml
-from ruamel.yaml import CommentedMap as _cm, CommentedSeq as _cs
+from ruamel.yaml import CommentedMap as _cm
+from ruamel.yaml import CommentedSeq as _cs
 
 _yaml = yaml.YAML()
-_safe_yaml = yaml.YAML(typ='safe')
+_safe_yaml = yaml.YAML(typ="safe")
 
 CommentedMap = _cm
 CommentedSeq = _cs
@@ -27,15 +28,13 @@ def safe_load(stream, version=None) -> Any:
     return _safe_yaml.load(stream)
 
 
-def dump(
-        data, stream: Any = None, *, transform: Any = None
-) -> Any:
+def dump(data, stream: Any = None, *, transform: Any = None) -> Any:
     return _yaml.dump(data, stream, transform=transform)
 
 
 def safe_load_yaml(file_path):
     try:
-        with open(file_path, 'r') as f:
+        with open(file_path, "r") as f:
             payload = safe_load(f)
     except yaml.YAMLError as e:
         print(e)
@@ -46,7 +45,7 @@ def safe_load_yaml(file_path):
 
 
 def round_trip_load_yaml(file_path):
-    with open(file_path, 'r') as f:
+    with open(file_path, "r") as f:
         try:
             payload = load(f)
         except yaml.YAMLError as e:
@@ -55,7 +54,5 @@ def round_trip_load_yaml(file_path):
     return payload
 
 
-def round_trip_dump(
-        data: Any,
-        stream=None):
+def round_trip_dump(data: Any, stream=None):
     return yaml.round_trip_dump(data, stream)
